<?php

namespace Litecms\FitserCommunity\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Litecms\FitserCommunity\Forms\FitserCommunity as FitserCommunityForm;
use Litecms\FitserCommunity\Http\Requests\FitserCommunityRequest;
use Litecms\FitserCommunity\Interfaces\FitserCommunityRepositoryInterface;
use Litecms\FitserCommunity\Repositories\Eloquent\Filters\FitserCommunityResourceFilter;
use Litecms\FitserCommunity\Repositories\Eloquent\Presenters\FitserCommunityListPresenter;

/**
 * Resource controller class for fitser_community.
 */
class FitserCommunityResourceController extends BaseController
{

    /**
     * Initialize fitser_community resource controller.
     *
     *
     * @return null
     */
    public function __construct(FitserCommunityRepositoryInterface $fitser_community)
    {
        parent::__construct();
        $this->form = FitserCommunityForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('litecms.fitser_community.modules'), 'fitser_community', guard_url('fitser_community'));
        $this->repository = $fitser_community;
    }

    /**
     * Display a list of fitser_community.
     *
     * @return Response
     */
    public function index(FitserCommunityRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(FitserCommunityResourceFilter::class)
            ->setPresenter(FitserCommunityListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('fitser_community::fitser_community.names'))
            ->view('fitser_community::fitser_community.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display fitser_community.
     *
     * @param Request $request
     * @param Model   $fitser_community
     *
     * @return Response
     */
    public function show(FitserCommunityRequest $request, FitserCommunityRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('fitser_community::fitser_community.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('fitser_community::fitser_community.show')
            ->output();
    }

    /**
     * Show the form for creating a new fitser_community.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(FitserCommunityRequest $request, FitserCommunityRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('fitser_community::fitser_community.name'))
            ->view('fitser_community::fitser_community.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new fitser_community.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FitserCommunityRequest $request, FitserCommunityRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('fitser_community::fitser_community.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('fitser_community/fitser_community/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/fitser_community/fitser_community'))
                ->redirect();
        }

    }

    /**
     * Show fitser_community for editing.
     *
     * @param Request $request
     * @param Model   $fitser_community
     *
     * @return Response
     */
    public function edit(FitserCommunityRequest $request, FitserCommunityRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('fitser_community::fitser_community.name'))
            ->view('fitser_community::fitser_community.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the fitser_community.
     *
     * @param Request $request
     * @param Model   $fitser_community
     *
     * @return Response
     */
    public function update(FitserCommunityRequest $request, FitserCommunityRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('fitser_community::fitser_community.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('fitser_community/fitser_community/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('fitser_community/fitser_community/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the fitser_community.
     *
     * @param Model   $fitser_community
     *
     * @return Response
     */
    public function destroy(FitserCommunityRequest $request, FitserCommunityRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('fitser_community::fitser_community.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('fitser_community/fitser_community/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('fitser_community/fitser_community/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
