<?php

namespace Litecms\FitserCommunity\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\FitserCommunity\Models\FitserCommunity;

class FitserCommunityPolicy
{

    /**
     * Determine if the given user can view the fitser_community.
     *
     * @param UserPolicyInterface $authUser
     * @param FitserCommunity $fitser_community
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, FitserCommunity $fitser_community)
    {
        if ($authUser->canDo('fitser_community.fitser_community.view') && $authUser->isAdmin()) {
            return true;
        }

        return $fitser_community->user_id == user_id() && $fitser_community->user_type == user_type();
    }

    /**
     * Determine if the given user can create a fitser_community.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('fitser_community.fitser_community.create');
    }

    /**
     * Determine if the given user can update the given fitser_community.
     *
     * @param UserPolicyInterface $authUser
     * @param FitserCommunity $fitser_community
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, FitserCommunity $fitser_community)
    {
        if ($authUser->canDo('fitser_community.fitser_community.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $fitser_community->user_id == user_id() && $fitser_community->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given fitser_community.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, FitserCommunity $fitser_community)
    {
        return $fitser_community->user_id == user_id() && $fitser_community->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given fitser_community.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, FitserCommunity $fitser_community)
    {
        if ($authUser->canDo('fitser_community.fitser_community.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given fitser_community.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, FitserCommunity $fitser_community)
    {
        if ($authUser->canDo('fitser_community.fitser_community.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
