<?php

namespace Litecms\FitserCommunity\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\FitserCommunity\FitserCommunity;

class FitserCommunityServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'fitser_community');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'fitser_community');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Litecms\FitserCommunity\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\FitserCommunity\Providers\RouteServiceProvider::class);
        // $this->app->register(\Litecms\FitserCommunity\Providers\EventServiceProvider::class);
        // $this->app->register(\Litecms\FitserCommunity\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.fitser_community', function($app)
        {
            return $this->app->make(FitserCommunity::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind FitserCommunity to repository
        $this->app->bind(
            'Litecms\FitserCommunity\Interfaces\FitserCommunityRepositoryInterface',
            \Litecms\FitserCommunity\Repositories\Eloquent\FitserCommunityRepository::class
        );
    }


    /**
     * Merges user's and fitser_community's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.fitser_community'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Litecms\FitserCommunity\Commands\FitserCommunity::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.fitser_community'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/fitser_community.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/fitser_community')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/fitser_community')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
